@@ -268,7 +268,7 @@ def delete_ldap_user(username):
 
 
 def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid, 
-               joomlagidNumber, gid, gidNumber, uid, loginShell, nocreatehome, homeDir, createGroup, 
+               joomlagidNumber, gid, gidNumber, uid, loginShell, nocreatehome, homeDir, skipCreateGroup, 
                skipldap, skipcms):
 	"""
 	hubname - for machines that have more than one hub, otherwise this will use the default hub for a server
@@ -285,7 +285,7 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 	loginShell - user's login shell
 	nocreatehome - skip creation of home directory
 	homeDir - path to user's home directory
-	createGroup - create a default group for new user, group name matches the username
+	skipCreateGroup - create a default group for new user, group name matches the username
 	skipldap - skip creating ldap info for this user
 	skipcms	- skip ldap info for this user
 	"""
@@ -343,7 +343,8 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 		print "skip cms insert and ldap, why bother?"
 		return(3)
 
-	if not createGroup:
+	# if the user doesn't want custom group for this user, they still need to be added to some group
+	if skipCreateGroup:
 		gidNumber = 100 # default to the users group
 		gid = 'users'
 
@@ -352,7 +353,10 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 		# create group for user named same as username (need group insert here for xprofiles addition below)
 		# Guess if user specifies a specific already created group for the new user and says create a new group for the 
 		# user, we'll override and create the new group with this logic
-		if createGroup:
+		import sys
+		sys.stderr.write("one\n")
+		if not skipCreateGroup:
+			sys.stderr.write("two\n")
 			gidNumber = hubzero.utilities.group._insert_jos_xgroups(db, username, username + " group")	
 			gid = username # group name same as user
 	
@@ -363,7 +367,7 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 		_insert_jos_users_password(db, userID, pw)
 	
 		# add user to new group (need xgroups insert after user creation because we need userid, I'd prefer to keep all group logic in one place)
-		if createGroup:
+		if not skipCreateGroup:
 			hubzero.utilities.group._insert_jos_xgroups_members(db, gidNumber, userID)
 		
 		# create home directory
@@ -384,7 +388,9 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 				print procStdErr
 
 	if not skipldap:
-		hubzero.utilities.group.add_ldap_group(username, username + " group", gidNumber)
+		if not skipCreateGroup:
+			hubzero.utilities.group.add_ldap_group(username, username + " group", gidNumber)
+			
 		add_ldap_user(username, gecos, pw, userID, homeDir, loginShell, gid, gidNumber)
 		
 	return(0)
